!function(){"use strict";function d(e){return(d=Object.setPrototypeOf?Object.getPrototypeOf:function(e){return e.__proto__||Object.getPrototypeOf(e)})(e)}function l(e,t){return(l=Object.setPrototypeOf||function(e,t){return e.__proto__=t,e})(e,t)}function f(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,[],function(){})),!0}catch(e){return!1}}function r(e,t,n){return(r=f()?Reflect.construct:function(e,t,n){var r=[null];r.push.apply(r,t);var o=new(Function.bind.apply(e,r));return n&&l(o,n.prototype),o}).apply(null,arguments)}function s(e){var n="function"==typeof Map?new Map:void 0;return(s=function(e){if(null===e||!function(e){return-1!==Function.toString.call(e).indexOf("[native code]")}(e))return e;if("function"!=typeof e)throw new TypeError("Super expression must either be null or a function");if(void 0!==n){if(n.has(e))return n.get(e);n.set(e,t)}function t(){return r(e,arguments,d(this).constructor)}return t.prototype=Object.create(e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),l(t,e)})(e)}function m(e,t){return!t||"object"!=typeof t&&"function"!=typeof t?function(e){if(void 0===e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return e}(e):t}function n(i){var e=function(){!function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function");e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,writable:!0,configurable:!0}}),t&&l(e,t)}(o,s(HTMLElement));var r=function(r){var o=f();return function(){var e,t=d(r);if(o){var n=d(this).constructor;e=Reflect.construct(t,arguments,n)}else e=t.apply(this,arguments);return m(this,e)}}(o);function o(){var e;!function(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}(this,o);var t=(e=r.call(this)).attachShadow({mode:"open"}),n=document.createElement("style");return n.textContent="\n      div.mermaid {\n        margin: 0;\n        overflow: visible;\n      }",t.appendChild(n),e}return o}();void 0===customElements.get("mermaid-div")&&customElements.define("mermaid-div",e);var t={startOnLoad:!1,theme:"default",flowchart:{htmlLabels:!1},er:{useMaxWidth:!1},sequence:{useMaxWidth:!1,noteFontWeight:"14px",actorFontSize:"14px",messageFontSize:"16px"}};mermaid.mermaidAPI.globalReset();var n=null;try{n=document.querySelector("[data-md-color-scheme]").getAttribute("data-md-color-scheme")}catch(e){n="default"}var r="undefined"==typeof mermaidConfig?t:mermaidConfig[n]||mermaidConfig.default||t;mermaid.initialize(r);for(var a=document.querySelectorAll("pre.".concat(i,", mermaid-div")),c=document.querySelector("body"),o=function(e){var r=a[e],o="mermaid-div"===r.tagName.toLowerCase()?r.shadowRoot.querySelector("pre.".concat(i)):r,t=document.createElement("div");t.style.visibility="hidden",t.style.display="display",t.style.padding="0",t.style.margin="0",c.appendChild(t),mermaid.mermaidAPI.render("_mermaind_".concat(e),function(e){for(var t="",n=0;n<e.childNodes.length;n++){var r=e.childNodes[n];if("code"===r.tagName.toLowerCase())for(var o=0;o<r.childNodes.length;o++){var i=r.childNodes[o];if("#text"===i.nodeName&&!/^\s*$/.test(i.nodeValue)){t=i.nodeValue;break}}}return t}(o),function(e){var t=document.createElement("div");t.className=i,t.innerHTML=e;var n=document.createElement("mermaid-div");n.shadowRoot.appendChild(t),r.parentNode.insertBefore(n,r),o.style.display="none",n.shadowRoot.appendChild(o),o!==r&&r.parentNode.removeChild(r)},t)},u=0;u<a.length;u++)o(u)}var e,t;t=new MutationObserver(function(e){e.forEach(function(e){if("attributes"===e.type){var t=e.target.getAttribute("data-md-color-scheme");t=t||"default",localStorage.setItem("data-md-color-scheme",t),"undefined"!=typeof mermaid&&n("mermaid")}})}),e=function(){t.observe(document.querySelector("body"),{attributeFilter:["data-md-color-scheme"]}),"undefined"!=typeof mermaid&&n("mermaid")},document.addEventListener("DOMContentLoaded",e),document.addEventListener("DOMContentSwitch",e)}();